@@ -51,7 +51,7 @@ The subclass constructor can generally be kept unaware of the implementation
 details of the device parameter, and find_supported_devices already accepts
 keyword arguments and forwards them to the driver constructor.
 
-Copyright (C) 2019–2022  Jonas Malaco and contributors
+Copyright Jonas Malaco and contributors
 SPDX-License-Identifier: GPL-3.0-or-later
 """
 
@@ -59,7 +59,7 @@ import logging
 import sys
 
 import usb
-from usb.backend.openusb import USBTimeoutError
+from usb.core import USBTimeoutError
 try:
     # The hidapi package, depending on how it's compiled, exposes one or two
     # top level modules: hid and, optionally, hidraw.  When both are available,
@@ -321,7 +321,7 @@ class PyUsbDevice:
 
     def write(self, endpoint, data, *, timeout=_DEFAULT_TIMEOUT_MS):
         """Write to endpoint."""
-        _LOGGER.debug('writting %d bytes: %r', len(data), LazyHexRepr(data))
+        _LOGGER.debug('writing %d bytes: %r', len(data), LazyHexRepr(data))
         try:
             return self.usbdev.write(endpoint, data, timeout=timeout)
         except USBTimeoutError:
@@ -473,7 +473,7 @@ class HidapiDevice:
         > first byte should be set to 0. The report data itself should begin
         > at the second byte.
         """
-        _LOGGER.debug('writting report 0x%02x with %d bytes: %r', data[0],
+        _LOGGER.debug('writing report 0x%02x with %d bytes: %r', data[0],
                       len(data) - 1, LazyHexRepr(data, start=1))
         res = self.hiddev.write(data)
         if res < 0:
